@@ -26,4 +26,9 @@ STATIC_ROOT = setting_overrides.get(
 STATIC_URL = setting_overrides.get(
     'STATIC_URL',
     settings.STATIC_URL,
+)
+
+REACT_EXTERNAL = setting_overrides.get(
+    'REACT_EXTERNAL',
+    'window.React',
 )
\ No newline at end of file
